# ImageCrawler: InstagramProfile

## Purpose

A Crawler for hash tag posts of [https://www.instagram.com](https://www.instagram.com).

## Config

### `tag_name`

- the HashTag on Instagram
- type: string
- example: "earthporn"
